# 31st International Symposium on Lattice Field Theory LATTICE 2013

LATTICE 2013 - (other lattice conferences)
29 July – 3 August, 2013
Mainz, Germany

The annual lattice symposium brings together a global community of researchers from theoretical particle physics and beyond, who employ numerical and computational methods to study the properties of strongly interacting physical systems, above all Quantum Chromodynamics (QCD), the theory describing the interactions of quarks and gluons. Topics include studies of the spectrum and structure of hadrons, lattice studies of matter under extreme conditions, hadronic contributions to weak decay amplitudes, as well as recent developments in simulation algorithms and computer hardware. The 2013 conference in Mainz was attended by over 500 participants from all over the globe, making it the biggest in this series so far.

This proceedings volume is dedicated to the memory of Nobel Laureate Kenneth G. Wilson (June 8, 1936 - June 15, 2013).

Sessions
Preface
Plenary sessions
Algorithms and Machines
Applications beyond QCD
Physics beyond the Standard Model
Chiral Symmetry
Non-zero Temperature and Density
Hadron Spectroscopy and Interactions
Hadron Structure
Standard Model Parameters and Renormalization
Theoretical Developments
Vacuum Structure and Confinement
Weak Decays and Matrix Elements
Special Session: Coding Efforts
Posters

Preface
Foreword PoS(LATTICE 2013)503 pdf H. Wittig
Ken Wilson Obituary PoS(LATTICE 2013)504 pdf A. Kronfeld
Plenary sessions
Heavy Flavour Physics Review PoS(LATTICE 2013)001 pdf A. El-Khadra
New Developments for Lattice Field Theory at Non-Zero Density PoS(LATTICE 2013)002 pdf C. Gattringer